==> org.opennms.features.topology.api-19.0.0-20161116.132622-219-sources.jar: org/opennms/features/topology/api/info/VertexInfoPanelItemProvider.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2016 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2016 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.features.topology.api.info;

import java.util.Collection;
import java.util.Optional;

import org.opennms.features.topology.api.GraphContainer;
import org.opennms.features.topology.api.topo.Vertex;
import org.opennms.features.topology.api.topo.VertexRef;

public abstract class VertexInfoPanelItemProvider extends SingleSelectedInfoPanelItemProvider<VertexRef> {

    @Override
    protected Optional<VertexRef> findSingleSelectedItem(GraphContainer container) {
        Collection<VertexRef> selectedVertexRefs = container.getSelectionManager().getSelectedVertexRefs();
        if (selectedVertexRefs.size() == 1) {
            final VertexRef vertexRef = selectedVertexRefs.iterator().next();
            Vertex vertex = container.getBaseTopology().getVertex(vertexRef);
            return Optional.ofNullable(vertex);
        }

        return Optional.empty();
    }
}

==> org.opennms.features.topology.api-24.0.0-20190121.063625-73-sources.jar: org/opennms/features/topology/api/info/VertexInfoPanelItemProvider.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2016 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2016 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.features.topology.api.info;

import java.util.Collection;
import java.util.Optional;

import org.opennms.features.topology.api.GraphContainer;
import org.opennms.features.topology.api.topo.Vertex;
import org.opennms.features.topology.api.topo.VertexRef;

public abstract class VertexInfoPanelItemProvider extends SingleSelectedInfoPanelItemProvider<VertexRef> {

    @Override
    protected Optional<VertexRef> findSingleSelectedItem(GraphContainer container) {
        Collection<VertexRef> selectedVertexRefs = container.getSelectionManager().getSelectedVertexRefs();
        if (selectedVertexRefs.size() == 1) {
            final VertexRef vertexRef = selectedVertexRefs.iterator().next();
            Vertex vertex = container.getTopologyServiceClient().getVertex(vertexRef);
            return Optional.ofNullable(vertex);
        }

        return Optional.empty();
    }
}
